@@ -8,6 +8,8 @@ from Crypto.PublicKey import RSA
 from ec2instances.ec2_instance_mapping import Ec2RemoteShellMapping
 from sshconf import empty_ssh_config_file, read_ssh_config
 
+from pyclvm._common.session import get_session
+
 _SSH_DIR: Final[str] = expanduser(join("~", ".ssh"))
 _SSH_CONFIG: Final[str] = join(_SSH_DIR, "config")
 
@@ -70,7 +72,7 @@ def new(instance_name: str, **kwargs: str) -> None:
     Returns:
         None
     """
-    instance = Ec2RemoteShellMapping(**kwargs)[instance_name]
+    instance = Ec2RemoteShellMapping(get_session(kwargs))[instance_name]
     profile = kwargs.get("profile", "default")
     private_key_name, pubkey = _save_keys(profile, instance_name)
     _update_ssh_config(instance_name, private_key_name, profile)
