@@ -1,9 +1,9 @@
-from pyclvm.ssm.session import start as start_session
+from pyclvm.ssm.session.start import start as start_session
 
 
 def start(instance_name: str, port: int, **kwargs: str) -> None:
     """
-    start ssh tunnelling to a Virtual Machine
+    start ssh tunnelling to a virtual machine
 
     Args:
         instance_name (str): Virtual Machine instance name
